@@ -4,7 +4,7 @@ import json
 serve_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "serve"))
 
 serve = {"__vue_deck": serve_path}
-scripts = ["/__vue_deck/vue-deck.umd.min.js"]
+scripts = ["__vue_deck/vue-deck.umd.min.js"]
 vue_use = ["VueDeck"]
 
 
